<?php

  // Require xml libraries
  require('xml.php');

  // Debug
  define(isdebug, 0);
  define(debugfile, '/temp/rpc.log');

  function do_log($filename, $body)
  {
    // Open log file
    $file=@fopen($filename,'a');
    if ($file)
    {
      fputs($file,date('Y-m-d H:i:s '));
      fputs($file,$body."\r\n");
      fclose($file);
    }
  }

  // Parses the xml rpc request into an array of calls with methods and params and returns this list
  //
  // $request XML RPC
  //
  // returns array[METHOD]
  //              [PARAMS]
  //

  function rpc_request(&$request) {

    // Parse xml 
    $xml = text_to_xml($request);

    // Method name
    $result[METHOD] = $xml->get_data('methodName');
    $result[PARAMS] = array();

    // Params
    $xml_params = &$xml->get_child('params');

    if ($xml_params) {
      // For every paramater
      for ($i=0;$i<count($xml_params->_children);$i++) {
        // Get child
        $child = $xml_params->_children[$i];

        // Get value param
	$value = $child->get_child('value');

	// If the type is specified strip it
	if ( count($value->_children[0]->_children) > 0 ) {
	  $value = $value->_children[0]->_children[0];
	}

        $param = $value->_children[0]->_data;

        // Add param
        $result[PARAMS][] = $param;
      }
    }

    // Return
    return $result;
  }

  // Reads the output array and creates the xml rpc response
  //
  // $output array[METHOD]
  //              [PARAMS]

  //
  // returns xml rpc

  function rpc_result(&$output) {

    // Set response
    $result = sprintf('<methodResponse><params><param><value>%s</value></param></params></methodResponse>', 
      htmlspecialchars($output[PARAMS][0])) . "\r\n";
    
    // Return
    return $result;
  }


  // Processes the RPC session
  //
  // $handler is the name of the handler function to be called

  function rpc_process($handler) {

    //Read requested data
    $request = file_get_contents("php://input");

    // Gzip
    $gzip = $_SERVER['HTTP_CONTENT_ENCODING'] == "gzip";
    if ($gzip) $request = gzuncompress($request);

    // Debug request
    if (isdebug) do_log(debugfile, "<<<\r\n" . $request);

    // RPC parse
    $call = rpc_request($request);

    // Call handler
    $output = call_user_func($handler, $call);

    // RPC get result
    $result = rpc_result($output);  

    // Debug response
    if (isdebug) do_log(debugfile, ">>>\r\n" . $result);

    // Gzip
    if ($gzip) {
      header('Content-Encoding: gzip');
      $result = gzcompress($result);
    }

    // Headers
    header('Content-Type: text/html');
    header('Content-Length: ' . strlen($result));

    // Body
    print($result);  
  }
?>