#!/bin/bash
#
# IceWarp Merak Mail Server
# (c) IceWarp Ltd. 2008
#
#       All rights reserved.
#
# http://www.icewarp.com
#
# file: license_operations.sh - wizard menu script
# version: 1.0
#

# include functions
if [ -z "$SCRIPTDIR" ]
    then
	echo "This wizard script requires to have \$SCRIPTDIR variable set."
	exit 1
fi

if [ -z "$FUNCTIONS_INCLUDED" ]
    then
	source ${SCRIPTDIR}/inc/functions.sh
fi

fnc_license_display()
{
    good "XML formatted output follows:"
    echo
    run_cmd_print_stdout_log "${MERAKDIR}/tool" display system c_license
    if [ $? -ne 0 ]
	then
	    bad "License display problem."
	    return 1
    fi
    return 0
}

fnc_license_export()
{
    getparam "Enter file name to save exported license:"
    run_cmd_print_stdout_log "${MERAKDIR}/tool" display system c_license > $PARAM
    if [ $? -eq 0 ]
	then
	    good "License saved to file ${PARAM}"
	else
	    bad "License export problem."
	    return 1
    fi
    return 0
}

fnc_license_online()
{
    getparam "Enter order ID:"
    ORDER_ID=$PARAM
    run_cmd_log "${MERAKDIR}/tool" modify system c_onlinelicense "${ORDER_ID}"
    if [ $? -eq 0 ]
	then
	    good "Request submitted"
	else
	    bad "Request submit problem, try again later."
	    return 1
    fi
    return 0
}

fnc_license_refkey_display()
{
    run_cmd_print_stdout_log "${MERAKDIR}/tool" display system c_reference
    return 0
}

fnc_license_refkey_export()
{
    getparam "Enter file name to save exported reference key:"
    run_cmd_print_stdout_log "${MERAKDIR}/tool" display system c_reference > $PARAM
    if [ $? -eq 0 ]
	then
	    good "Reference key saved to file ${PARAM}"
	else
	    bad "Reference key query problem."
	    return 1
    fi
    return 0
}

SCRIPT_NAME=`basename $0`
good ""
case $SCRIPT_NAME in
    "license_display")
	fnc_license_display
	;;
    "license_export")
	fnc_license_export
	;;
    "license_online")
	fnc_license_online
	;;
    "license_refkey_display")
	fnc_license_refkey_display
	;;
    "license_refkey_export")
	fnc_license_refkey_export
	;;
    *)
	echo "Script called for unknown operation: ${SCRIPT_NAME}"
	exit 1
	;;
esac

exit 0
